@@ -431,7 +431,8 @@ def make_fastq(lib, fragment, buf, f, flowcell, numbase = None,
                                                                     n_count * 100.0 / (read_count * len(dna))))
     out.flush()
 
-def make_csfasta(lib, fragment, buf_cs, buf_qual, f, flowcell, numbase = None, progress_mark = 50000, out=sys.stdout):
+def make_csfasta(lib, fragment, buf_cs, buf_qual, f, flowcell, 
+                 numbase = None, progress_mark = 50000, out=sys.stdout):
     read_count = long(0)
     inc = long(1)
 
